@@ -1,9 +1,8 @@
 ## ----create_tmp_dirs----------------------------------------------------------
-tmpdir <- tempdir()
-if (.Platform$OS.type == "windows") tmpdir <- normalizePath(tmpdir, winslash = "/")
+tmpdir <- fs::path_tidy(tempdir())
 
-registry_tmp <- file.path(tmpdir, "registry")
-data_dir_tmp <- file.path(tmpdir, "data_dir")
+registry_tmp <- fs::path(tmpdir, "registry")
+data_dir_tmp <- fs::path(tmpdir, "data_dir")
 
 if (!file.exists(registry_tmp)){
   dir.create (registry_tmp)
@@ -12,6 +11,9 @@ if (!file.exists(registry_tmp)){
 }
 if (!file.exists(data_dir_tmp)) dir.create(data_dir_tmp)
 
+regdir_envvar <- Sys.getenv("CORPUS_REGISTRY")
+Sys.setenv(CORPUS_REGISTRY = registry_tmp)
+
 ## ----load_pkgs----------------------------------------------------------------
 library(cwbtools)
 library(data.table)
@@ -63,13 +65,13 @@ UNGA$encode(
   compress = FALSE
   )
 
-## ----check_use, eval = TRUE---------------------------------------------------
-library(RcppCWB)
-id_peace <- cl_str2id(
+## -----------------------------------------------------------------------------
+RcppCWB::cqp_initialize()
+id_peace <- RcppCWB::cl_str2id(
   corpus = "UNGA", p_attribute = "word",
   str = "peace", registry = registry_tmp
 )
-cpos_peace <- cl_id2cpos(
+cpos_peace <- RcppCWB::cl_id2cpos(
   corpus = "UNGA", p_attribute = "word",
   id = id_peace, registry = registry_tmp
 )
@@ -78,11 +80,11 @@ tab <- data.frame(
   i = unlist(lapply(1:length(cpos_peace), function(x) rep(x, times = 11))),
   cpos = unlist(lapply(cpos_peace, function(x) (x - 5):(x + 5)))
   )
-tab[["id"]] <- cl_cpos2id(
+tab[["id"]] <- RcppCWB::cl_cpos2id(
   corpus = "UNGA", p_attribute = "word",
   cpos = tab[["cpos"]], registry = registry_tmp
 )
-tab[["str"]] <- cl_id2str(
+tab[["str"]] <- RcppCWB::cl_id2str(
   corpus = "UNGA", p_attribute = "word",
   id = tab[["id"]], registry = registry_tmp
 )
@@ -130,14 +132,14 @@ Austen$encode(
 )
 
 ## -----------------------------------------------------------------------------
-cqp_reset_registry(registry = registry_tmp)
+RcppCWB::cqp_reset_registry(registry = registry_tmp)
 
 ## -----------------------------------------------------------------------------
 corpus <- "AUSTEN"
 token <- "pride"
 p_attr <- "word"
 id <- RcppCWB::cl_str2id(corpus = corpus, p_attribute = p_attr, str = token, registry = registry_tmp)
-cpos <- cl_id2cpos(corpus = corpus, p_attribute = p_attr, id = id, registry = registry_tmp)
+cpos <- RcppCWB::cl_id2cpos(corpus = corpus, p_attribute = p_attr, id = id, registry = registry_tmp)
 count <- length(cpos)
 count
 
@@ -188,11 +190,11 @@ Reuters$encode(
 )
 
 ## ---- message = FALSE, results = FALSE----------------------------------------
-cqp_reset_registry(registry = registry_tmp)
+RcppCWB::cqp_reset_registry(registry = registry_tmp)
 
 ## -----------------------------------------------------------------------------
-id <- cl_str2id(corpus = "REUTERS", p_attribute = "word", str = "oil", registry = registry_tmp)
-cpos <- cl_id2cpos(corpus = "REUTERS", p_attribute = "word", id = id, registry = registry_tmp)
+id <- RcppCWB::cl_str2id(corpus = "REUTERS", p_attribute = "word", str = "oil", registry = registry_tmp)
+cpos <- RcppCWB::cl_id2cpos(corpus = "REUTERS", p_attribute = "word", id = id, registry = registry_tmp)
 count <- length(cpos)
 count
 
@@ -200,3 +202,5 @@ count
 unlink(registry_tmp, recursive = TRUE)
 unlink(data_dir_tmp, recursive = TRUE)
 
+Sys.setenv(CORPUS_REGISTRY = regdir_envvar)
+
